@@ -39,13 +39,13 @@ void about_dialog_open(SensorsApplet *sensors_applet) {
                   "version", PACKAGE_VERSION,
                   "copyright", _("Copyright \xc2\xa9 2005-2009 Alex Murray\n"
                                  "Copyright \xc2\xa9 2011 Stefano Karapetsas\n"
-                                 "Copyright \xc2\xa9 2012-2019 MATE developers"),
+                                 "Copyright \xc2\xa9 2012-2020 MATE developers"),
                   "authors", authors,
                   "documenters", authors,
                   /* To translator: Put your name here to show up in the About dialog as the translator */
                   "translator-credits", _("translator-credits"),
                   "logo-icon-name", SENSORS_APPLET_ICON,
-                  "website", "http://www.mate-desktop.org",
+                  "website", "https://mate-desktop.org",
                   NULL);
 
 }
