@@ -417,12 +417,13 @@ void prefs_dialog_open(SensorsApplet *sensors_applet) {
     prefs_dialog->dialog = GTK_DIALOG(gtk_dialog_new_with_buttons(_("Sensors Applet Preferences"),
                                                                   NULL,
                                                                   0,
-                                                                  GTK_STOCK_HELP,
+                                                                  "gtk-help",
                                                                   GTK_RESPONSE_HELP,
-                                                                  GTK_STOCK_CLOSE,
+                                                                  "gtk-close",
                                                                   GTK_RESPONSE_CLOSE,
                                                                   NULL));
 
+
     gtk_window_set_icon_name(GTK_WINDOW(prefs_dialog->dialog), "mate-sensors-applet");
 
     g_object_set(prefs_dialog->dialog,
@@ -827,14 +828,16 @@ void prefs_dialog_open(SensorsApplet *sensors_applet) {
     /* when selection is changed, make sure sensor_config button is activated */
 
     /* Create buttons for user to interact with sensors tree */
-    prefs_dialog->sensor_up_button = GTK_BUTTON(gtk_button_new_from_stock(GTK_STOCK_GO_UP));
+    prefs_dialog->sensor_up_button = GTK_BUTTON(gtk_button_new_with_mnemonic(_("_Up")));
+    gtk_button_set_image(prefs_dialog->sensor_up_button, gtk_image_new_from_icon_name("go-up", GTK_ICON_SIZE_BUTTON));
     gtk_widget_set_sensitive(GTK_WIDGET(prefs_dialog->sensor_up_button), FALSE);
 
     g_signal_connect(prefs_dialog->sensor_up_button, "clicked",
                      G_CALLBACK(prefs_dialog_sensor_up_button_clicked),
                      prefs_dialog);
 
-    prefs_dialog->sensor_down_button = GTK_BUTTON(gtk_button_new_from_stock(GTK_STOCK_GO_DOWN));
+    prefs_dialog->sensor_down_button = GTK_BUTTON(gtk_button_new_with_mnemonic(_("_Down")));
+    gtk_button_set_image(prefs_dialog->sensor_down_button, gtk_image_new_from_icon_name("go-down", GTK_ICON_SIZE_BUTTON));
     gtk_widget_set_sensitive(GTK_WIDGET(prefs_dialog->sensor_down_button), FALSE);
 
     g_signal_connect(prefs_dialog->sensor_down_button, "clicked",
@@ -867,7 +870,8 @@ void prefs_dialog_open(SensorsApplet *sensors_applet) {
     /* Sensor Config button */
     /* initially make button insensitive until user selects a row
        from the sensors tree */
-    prefs_dialog->sensor_config_button = GTK_BUTTON(gtk_button_new_from_stock(GTK_STOCK_PROPERTIES));
+    prefs_dialog->sensor_config_button = GTK_BUTTON(gtk_button_new_with_mnemonic(_("_Properties")));
+    gtk_button_set_image(prefs_dialog->sensor_config_button, gtk_image_new_from_icon_name("document-properties", GTK_ICON_SIZE_BUTTON));
     g_object_set(prefs_dialog->sensor_config_button,
                  "sensitive", FALSE,
                  NULL);
